@@ -26,11 +26,11 @@ yourself, they will get created for you by C<Carp::Parse::Redact>.
 
 =head1 VERSION
 
-Version 1.1.1
+Version 1.1.3
 
 =cut
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.1.3';
 
 
 =head1 SYNOPSIS
@@ -127,6 +127,12 @@ sub get_redacted_line
 		$redacted_arguments_string = "($redacted_arguments_string)"
 			if scalar( @$redacted_arguments_list ) == 1;
 		
+		# Data::Dump::dump() may format the output on more than one line.
+		# We make sure that the indentation of the original line is carried
+		# here to the new lines.
+		my ( $indentation ) = $line =~ /^(\s*)/;
+		$redacted_arguments_string =~ s/(\r?\n)/$1$indentation/gs;
+		
 		$line =~ s/\(\Q$arguments_string\E\)/$redacted_arguments_string/x;
 	}
 	
@@ -190,10 +196,11 @@ and write code for them!
 
 Copyright 2012 Kate Kirby & Guillaume Aubert.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License.
+This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.
 
-See http://dev.perl.org/licenses/ for more information.
+This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/
 
 =cut
 
